SocialMediaApp enum

Inheritance
Available extensions

Values

whatsapp → const SocialMediaApp
instagram → const SocialMediaApp
linkedin → const SocialMediaApp
facebook → const SocialMediaApp
twitter → const SocialMediaApp
tiktok → const SocialMediaApp
telegram → const SocialMediaApp

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SocialMediaApp>
A constant List of the values in this enum, in order of their declaration.